import numpy as np
import pandas as pd
from scipy import stats
import time
import math
from math import sqrt
from sklearn.metrics import r2_score, mean_squared_error, mean_absolute_error, mean_absolute_percentage_error,max_error,explained_variance_score

# 模型评估指标
def metrics(y_train_true, y_train_pre, y_test_true, y_test_pre):
    """
    计算模型评估指标。

    参数：
    y_train_true：array-like，训练集真实值。
    y_train_pre：array-like，训练集预测值。
    y_test_true：array-like，测试集真实值。
    y_test_pre：array-like，测试集预测值。

    返回值：
    result1：str，训练集评估结果。
    result2：str，测试集评估结果。
    """
    # 模型评估指标
    r2_train = r2_score(y_train_true, y_train_pre)
    r2_train = round(r2_train, 16)
    r2_test = r2_score(y_test_true, y_test_pre)
    r2_test = round(r2_test, 16)
    mse_train = mean_squared_error(y_train_true, y_train_pre)
    mse_train = round(mse_train, 16)
    mse_test = mean_squared_error(y_test_true, y_test_pre)
    mse_test = round(mse_test, 16)
    rmse_train = sqrt(mse_train)
    rmse_test = sqrt(mse_test)
    mape_train = mean_absolute_percentage_error(y_train_true, y_train_pre)
    mape_test = mean_absolute_percentage_error(y_test_true, y_test_pre)
    mae_train = mean_absolute_error(y_train_true, y_train_pre)
    mae_test = mean_absolute_error(y_test_true, y_test_pre)
    explained_variance_train = explained_variance_score(y_train_true, y_train_pre)
    explained_variance_test = explained_variance_score(y_test_true, y_test_pre)
    max_error_train = max_error(y_train_true, y_train_pre)
    max_error_test = max_error(y_test_true, y_test_pre)

    # 评估结果
    result1 = '''
    Train R² = {:.4f}
    Train MSE = {:.4f}
    Train RMSE = {:.4f}
    Train MAE = {:.4f}
    Train MAPE = {:.4f}
    Train Explained Variance = {:.4f}
    Train Max Error = {:.4f}
    '''.format(r2_train, mse_train, rmse_train, mae_train, mape_train, explained_variance_train, max_error_train)
    print('训练集评价指标：', result1)
    result2 = '''
    Test R² = {:.4f}
    Test MSE = {:.4f}
    Test RMSE = {:.4f}
    Test MAE = {:.4f}
    Test MAPE = {:.4f}
    Test Explained Variance = {:.4f}
    Test Max Error = {:.4f}
    '''.format(r2_test, mse_test, rmse_test, mae_test, mape_test, explained_variance_test, max_error_test)
    print('测试集评价指标：', result2)
    return result1, result2

# 模型评估指标
def metrics_test(y_test_true, y_test_pre):
    """
    计算测试集模型评估指标。
    参数：
    y_test_true：array-like，测试集真实值。
    y_test_pre：array-like，测试集预测值。
    返回值：
    result：str，测试集评估结果。
    """
    # 模型评估指标
    r2_test = r2_score(y_test_true, y_test_pre)
    r2_test = round(r2_test, 16)
    mse_test = mean_squared_error(y_test_true, y_test_pre)
    mse_test = round(mse_test, 16)
    rmse_test = sqrt(mse_test)
    mape_test = mean_absolute_percentage_error(y_test_true, y_test_pre)
    mae_test = mean_absolute_error(y_test_true, y_test_pre)
    explained_variance_test = explained_variance_score(y_test_true, y_test_pre)
    max_error_test = max_error(y_test_true, y_test_pre)
    result = '''
    Test R² = {:.4f}
    Test MSE = {:.4f}
    Test RMSE = {:.4f}
    Test MAE = {:.4f}
    Test MAPE = {:.4f}
    Test Explained Variance = {:.4f}
    Test Max Error = {:.4f}
    '''.format(r2_test, mse_test, rmse_test, mae_test, mape_test, explained_variance_test, max_error_test)
    print('测试集评价指标：', result)
    return result



import seaborn as sns
import matplotlib.pyplot as plt
# 局部放大
def plot_local(Y_train, Y_test, Y_pre_test, xlim_local, ylim_local):
    '''
    绘制局部放大图像。
    y_train_true：array-like，训练集真实值。
    y_train_pre：array-like，训练集预测值。
    y_test_true：array-like，测试集真实值。
    y_test_pre：array-like，测试集预测值。
    xlim_local：tuple，x轴的范围。
    ylim_local：tuple，y轴的范围。
    '''
    fig = plt.figure(figsize=(12, 4))

    # 创建第一个子图，显示整体图像
    ax1 = plt.subplot2grid((1, 3), (0, 0), colspan=2)
    ax1.tick_params(axis='x', direction='in')
    ax1.tick_params(axis='y', direction='in')
    ax1.plot(range(len(Y_train), len(Y_train) + len(Y_test)), Y_test, 'k--', alpha=0.5, label='Actual')
    ax1.plot(range(len(Y_train), len(Y_train) + len(Y_pre_test)), Y_pre_test, color='blue', ls='-', alpha=0.5, label='Predicted')
    ax1.legend()
    ax1.set_xlabel('Data Sample Index')
    ax1.set_ylabel('ROP, m/h')
    # ax1.set_xlim(19809,22011)
    # ax1.set_ylim(-5, 35)
    ax1.legend(loc=2)

    # 创建第二个子图，显示局部放大图像
    ax2 = plt.subplot2grid((1, 3), (0, 2))
    ax2.tick_params(axis='x', direction='in')
    ax2.tick_params(axis='y', direction='in')
    ax2.plot(range(len(Y_train), len(Y_train) + len(Y_test)), Y_test, 'k--', alpha=0.5, marker='o',label='Actual')
    ax2.plot(range(len(Y_train), len(Y_train) + len(Y_pre_test)), Y_pre_test, color='blue', ls='-', marker='o',alpha=0.5, label='Predicted')
    ax2.legend()
    ax2.set_xlabel('Data Sample Index')
    ax2.set_ylabel('ROP, m/h')
    ax2.legend(loc=2)
    ax2.set_xlim(xlim_local)
    ax2.set_ylim(ylim_local)
    # ax2.set_ylim(16, 20)

    # 添加垂直直线
    # ax1.axvline(x=21750, color='red', linestyle='--')
    # ax1.axvline(x=21800, color='red', linestyle='--')

    plt.tight_layout()
    # plt.savefig("./figure/局部放大预测图蓝色.svg",dpi=600,bbox_inches='tight')
    plt.show()


from bayes_opt import BayesianOptimization

def objective_function(设计充填系数, 最大排量, 最大砂比, 最大砂量, 砂浆量, 射孔簇数, 射孔测深, 射孔垂深, 净射孔垂深充填系数, 设计净液量):
    # 合并固定值和可调参数
    features = {**geo_input, '设计充填系数': 设计充填系数, '最大排量': 最大排量, '最大砂比': 最大砂比, '最大砂量': 最大砂量,
                '砂浆量': 砂浆量, '射孔簇数': 射孔簇数, '射孔测深': 射孔测深, '射孔垂深': 射孔垂深,
                '净射孔垂深充填系数': 净射孔垂深充填系数, '设计净液量': 设计净液量}
    # 使用固定值和可调参数进行预测
#     predictions = model.predict([list(features.values())])
    
    # ————————————AutoGluon——————————————
    # 转换为TabularDataset或pandas.DataFrame
    data = TabularDataset(pd.DataFrame([list(features.values())], columns=list(features.keys())))
    predictions = predictor_best.predict(data)
    # ————————————AutoGluon——————————————
    
    
    # 保存迭代结果到DataFrame
    global opt_results
    opt_results = opt_results._append({'设计充填系数': 设计充填系数, '最大排量': 最大排量, '最大砂比': 最大砂比, '最大砂量': 最大砂量,
                                    '砂浆量': 砂浆量, '射孔簇数': 射孔簇数, '射孔测深': 射孔测深, '射孔垂深': 射孔垂深,
                                    '净射孔垂深充填系数': 净射孔垂深充填系数, '设计净液量': 设计净液量, '预测产量值': predictions[0]}, ignore_index=True)
    
    return predictions[0]


import pandas as pd
# 灰色关联分析封装函数
def normalize_data(data, method='mean'):
    '''数据无量纲化处理'''
    if method == 'mean':
        return data / data.mean(axis=0)
    elif method == 'first':
        return data / data.iloc[0, :]
    elif method == 'max':
        return data / data.max()
    elif method == 'min':
        return data / data.min()
def gray(input_df, method='mean', target=None, rho=0.5):
    '''
    进行灰色关联分析，计算权重。
    
    参数：
    input_df (pd.DataFrame): 输入的数据框dataframe格式
    method (str): 数据无量纲化方法，默认为'mean'
    target (int): 母序列所在的序号位置，默认为 None，索引是从0开始的，None表示最后一列
    rho (float): 对应系数，默认为0.5
    
    返回：
    pd.DataFrame: 包含权重的数据框
    #### 调用示例：result = gray(input_df, target=1)，输入数据input_df，target此时表示第二列
    '''
    try:
        # 1. 进行无量纲化
        df_normalized = normalize_data(input_df, method)

        # 2. 获取 x 和 y
        if target is None:
            target = len(df_normalized.columns) - 1
        
        x = df_normalized.drop(input_df.columns[target], axis=1)
        y = df_normalized.iloc[:, target]

        # 3. 求解系数
        abs_xik = abs(x.sub(y, axis=0))
        a, b = abs_xik.min().min(), abs_xik.max().max()
        coef = (a + rho * b) / (abs_xik + rho * b)
        coef_m = coef.mean()

        # 4. 返回结果并排序
        result = pd.DataFrame({'Weight': coef_m}).sort_values('Weight', ascending=False)
        return result

    except Exception as e:
        print(f"An error occurred: {e}")
        return pd.DataFrame()  # 返回一个空的数据框表示出错



def preprocess_data(df_data):
    df_data = df_data[(df_data['30天累产油'] != 0) | (df_data['60天累产油'] != 0)]
    df_data = df_data[df_data['设计装填系数lbs/ft'] != 0]

    # Rename columns
    rename_dict = {
        '设计装填系数lbs/ft': '设计充填系数',
        '最大压裂液泵注速率 bpm': '最大排量',
        '最大支撑剂浓度(lb/gal)': '最大砂比',
        '支撑剂质量(lb)': '最大砂量',
        '真实垂直深度的有效射孔区域内，每英尺的单位重量lbs/ft TVD Net Perfs': '净射孔垂深充填系数',
        '支撑剂(lb/ft)': '实际充填系数',
        '最大处理压力(psi).1': '最大油压',
        '最大环空压力(psi).1': '最大套压',
        '设计填充度(%)': '设计前置液百分比',
        '底部射孔到顶部射孔测深差(m)': '射孔测深',
        '底部射孔到顶部射孔垂深差(m)': '射孔垂深',
        '清洗垫液体积(bbl)': '设计净液量',
        '1号压裂液体体积（bbl）对HRWP的0.5磅/加仑': '1号压裂液体积',
        '2号压裂液体体积 (bbl)/1-4 ppg': '2号压裂液体积',
        '3号压裂液体体积 (bbl)': '3号压裂液体积',
        '4号压裂液体体积 (gal)/4-6 ppg': '4号压裂液体积',
        '5号压裂液体体积 (gal)': '5号压裂液体积',
        '6号压裂液体体积 (gal)/4-8 ppg': '6号压裂液体积',
        '7号压裂液体体积 (gal)/6-8 ppg': '7号压裂液体积',
        '8号压裂液体体积 (gal)': '8号压裂液体积',
        '9号压裂液体体积 (gal)/8-10 ppg': '9号压裂液体积',
        '10号压裂液体体积 (gal)': '10号压裂液体积',
        '冲洗浆液体积 (gal)': 'Flush进液量体积',
        '垫液体积 (gal)': '砂浆量'
    }
    df_data.rename(columns=rename_dict, inplace=True)
    #———————————选择特征——————————————

    feature_label = ['设计充填系数','最大排量','最大砂比','最大砂量','砂浆量','射孔簇数','设计净液量',
                    '射孔测深','射孔垂深',
                    '最大油压','最大套压',
    #                  '净射孔垂深充填系数',
                    '垂厚m','地层电阻率Ω.m','孔隙度%','平均渗透率mD','含烃饱和度%','泥质含量%']

    #—————————————————————————
    target_label     = ['30天累产油']
    target_label_60  = ['60天累产油']
    # 30天累产油, 30天平均累产油, 60天累产油, 60天平均累产油, 90天累产油, 90天平均累产油, 180天累产油, 180天平均累产油, 360天累产油, 360天平均累产油
    #—————————————————————————

    new_data_30_all   = df_data[feature_label+['30天累产油']]
    new_data_30_mean  = df_data[feature_label+['30天平均累产油']]

    new_data_60_all   = df_data[feature_label+['60天累产油']]
    new_data_60_mean  = df_data[feature_label+['60天平均累产油']]

    new_data_90_all   = df_data[feature_label+['90天累产油']]
    new_data_90_mean  = df_data[feature_label+['90天平均累产油']]

    new_data_180_all  = df_data[feature_label+['180天累产油']]
    new_data_180_mean = df_data[feature_label+['180天平均累产油']]

    new_data_360_all  = df_data[feature_label+['360天累产油']]
    new_data_360_mean = df_data[feature_label+['360天平均累产油']]

    #———————————选择数据——————————————
    df_data   = df_data[feature_label+ target_label]


    for col in df_data.columns:
        null_count = df_data[col].isnull().sum()
        print(f"列 {col} 中的空值数量为：{null_count}")

    # ————————————0-空值填充————————————————
    df_data.fillna(0, inplace=True)

    def encode_columns(df_data, *columns):
        '''
        获取指定列不同的类别，创建编码字典，将指定列进行替代为编码值
        该函数会替代原始数据
        '''
        for column_name in columns:
            unique_labels = df_data[column_name].unique()
            label_encoding = {label: index for index, label in enumerate(unique_labels)}
            df_data[column_name] = df_data[column_name].replace(label_encoding)
            
            
    # ————————查看非数值类型列————————
    non_numeric_features = df_data.select_dtypes(exclude=['number']).columns.tolist()

    # print(non_numeric_features)

    # 例如处理"某列"的编码
    # encode_columns(df_data, '区块')

    # ——————————std-异常值删除——————————
    def remove_outliers(df):
        skipped_cols = []
        for column in df.columns:
            try:
                std = df[column].std()
                df = df[(df[column] >= df[column].mean() - 3*std) & (df[column] <= df[column].mean() + 3*std)]
            except:
                skipped_cols.append(column)
        return df, skipped_cols

    # 使用示例：
    outliers_data = df_data
    df_std, skipped_columns = remove_outliers(outliers_data)

    df_data = df_std

    return df_data


import os
import pandas as pd
import numpy as np
import seaborn as sns
from scipy import stats
import math
from math import sqrt
import shap
import time
import matplotlib.pyplot as plt
from matplotlib import rcParams
from matplotlib import font_manager
from matplotlib.patches import Rectangle
from matplotlib.font_manager import FontProperties
from matplotlib_inline.backend_inline import set_matplotlib_formats
from mpl_toolkits.axes_grid1.inset_locator import inset_axes
from tqdm import tqdm, trange
from minepy import MINE
from sklearn.tree import DecisionTreeRegressor
from sklearn.ensemble import RandomForestRegressor
from datetime import datetime
from scipy.stats import rankdata, pointbiserialr
from sklearn.model_selection import train_test_split, cross_val_score
from sklearn.preprocessing import MinMaxScaler
from sklearn.metrics import r2_score, explained_variance_score, mean_squared_error, mean_absolute_error, mean_absolute_percentage_error, max_error
from mpl_toolkits.mplot3d import Axes3D
from scipy.interpolate import griddata
from autogluon.tabular import TabularDataset, TabularPredictor
import warnings
warnings.filterwarnings('ignore')
# plt.rcParams['font.sans-serif'] =['Times New Roman'] 
plt.rcParams['axes.unicode_minus'] = False
plt.rcParams['font.family'] = ['STFangsong']
plt.rcParams['xtick.direction'] = 'in'
plt.rcParams['ytick.direction'] = 'in'
pd.set_option('display.max_columns', False)
pd.set_option('display.max_rows', False)



# 模型评估指标
def mzc_metrics(y_train_true, y_train_pre, y_test_true, y_test_pre):
    """
    计算模型评估指标。

    参数：
    y_train_true：array-like，训练集真实值。
    y_train_pre：array-like，训练集预测值。
    y_test_true：array-like，测试集真实值。
    y_test_pre：array-like，测试集预测值。

    返回值：
    result1：str，训练集评估结果。
    result2：str，测试集评估结果。
    """
    # 模型评估指标
    r2_train = r2_score(y_train_true, y_train_pre)
    r2_train = round(r2_train, 16)
    r2_test = r2_score(y_test_true, y_test_pre)
    r2_test = round(r2_test, 16)
    mse_train = mean_squared_error(y_train_true, y_train_pre)
    mse_train = round(mse_train, 16)
    mse_test = mean_squared_error(y_test_true, y_test_pre)
    mse_test = round(mse_test, 16)
    rmse_train = sqrt(mse_train)
    rmse_test = sqrt(mse_test)
    mape_train = mean_absolute_percentage_error(y_train_true, y_train_pre)
    mape_test = mean_absolute_percentage_error(y_test_true, y_test_pre)
    mae_train = mean_absolute_error(y_train_true, y_train_pre)
    mae_test = mean_absolute_error(y_test_true, y_test_pre)
    explained_variance_train = explained_variance_score(y_train_true, y_train_pre)
    explained_variance_test = explained_variance_score(y_test_true, y_test_pre)
    max_error_train = max_error(y_train_true, y_train_pre)
    max_error_test = max_error(y_test_true, y_test_pre)

    # 评估结果
    result1 = '''
    Train R² = {:.16f}
    Train MSE = {:.16f}
    Train RMSE = {:.16f}
    Train MAE = {:.16f}
    Train MAPE = {:.16f}
    Train Explained Variance = {:.16f}
    Train Max Error = {:.16f}
    '''.format(r2_train, mse_train, rmse_train, mae_train, mape_train, explained_variance_train, max_error_train)
    print('训练集评价指标：', result1)
    result2 = '''
    Test R² = {:.16f}
    Test MSE = {:.16f}
    Test RMSE = {:.16f}
    Test MAE = {:.16f}
    Test MAPE = {:.16f}
    Test Explained Variance = {:.16f}
    Test Max Error = {:.16f}
    '''.format(r2_test, mse_test, rmse_test, mae_test, mape_test, explained_variance_test, max_error_test)
    print('测试集评价指标：', result2)
    return result1, result2


def model_train(df_train, label, time_limit, k_folds):
    """
    使用给定的训练数据和参数训练模型。

    参数：
        df_train (pandas.DataFrame)：训练数据。
        label (str)：目标标签列名。
        time_limit (int)：训练模型的最大时间限制。
        k_folds (int)：交叉验证的折数。

    返回：
        tuple：包含训练好的模型、训练数据的预测值、测试数据的预测值和评估指标的元组。
    """
    # RMSE 模型评价指标
    metric = 'root_mean_squared_error'
    # 预测模型 案例01
    predictor_01 = TabularPredictor(label=target_label, problem_type="regression", eval_metric=metric).fit(
        train_data=df_train, time_limit=time_limit, num_bag_folds=k_folds, verbosity=1, presets='best_quality')
    # Model 01
    Evaluate_01_Train = predictor_01.evaluate(df_train)
    print(f'{label}训练集指标:', Evaluate_01_Train)
    Evaluate_01_Test = predictor_01.evaluate(df_test)
    print(f'{label}测试集指标:', Evaluate_01_Test)
    # 01
    predictor_01_Ytrain = predictor_01.predict(X_train)  # 预测数据
    predictor_01_Ytest = predictor_01.predict(X_test)
    auto_predictor_metrics1 = mzc_metrics(Y_train, predictor_01_Ytrain, Y_test, predictor_01_Ytest)
    return predictor_01, predictor_01_Ytrain, predictor_01_Ytest, auto_predictor_metrics1



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pipenv install twine --dev

import io
import os
import sys
from shutil import rmtree
from distutils.core import setup
from setuptools import find_packages

  
NAME = 'autofracture'
DESCRIPTION = 'Support the intelligent fracturing process.'
URL = 'https://github.com/MoonCapture/AutoFracture'
EMAIL = 'mzc1226@126.com'
AUTHOR = 'mzc'
REQUIRES_PYTHON = '>=3.6.0'
VERSION = '0.1.0'

# What packages are required for this module to be executed? # 执行这个模块需要什么包?
REQUIRED = [
    'numpy', 'pandas', 'scikit-learn', 'matplotlib', 'seaborn', 'scipy','autogluon'
]
# What packages are optional? # 什么包是可选的?
EXTRAS = {
    # 'fancy feature': ['django'],
}


# Import the README and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file!
here = os.path.abspath(os.path.dirname(__file__))
try:
    with io.open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
        long_description = '\n' + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION


setup(
      name=NAME,  
      version=VERSION,  # 版本号
      description=DESCRIPTION,
      long_description=long_description,
      long_description_content_type='text/markdown',
      author=AUTHOR,
      author_email=EMAIL,
      python_requires=REQUIRES_PYTHON,
      url=URL,
      install_requires=REQUIRED,
      extras_require=EXTRAS,
      include_package_data=True,
      packages=find_packages(),
      platforms=["all"],
      license='MIT License',
      classifiers=[
          'Intended Audience :: Developers',
          'Operating System :: OS Independent',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Programming Language :: Python :: 3.9',
          'Programming Language :: Python :: 3.10',
          'Topic :: Software Development :: Libraries'
      ],
      )



import os
import pandas as pd
import numpy as np
import seaborn as sns
from scipy import stats
import math
from math import sqrt
import shap
import time
import matplotlib.pyplot as plt
from matplotlib import rcParams
from matplotlib import font_manager
from matplotlib.patches import Rectangle
from matplotlib.font_manager import FontProperties
from matplotlib_inline.backend_inline import set_matplotlib_formats
from mpl_toolkits.axes_grid1.inset_locator import inset_axes
from tqdm import tqdm, trange
from minepy import MINE
from sklearn.tree import DecisionTreeRegressor
from sklearn.ensemble import RandomForestRegressor
from datetime import datetime
from scipy.stats import rankdata, pointbiserialr
from sklearn.model_selection import train_test_split, cross_val_score
from sklearn.preprocessing import MinMaxScaler
from sklearn.metrics import r2_score, explained_variance_score, mean_squared_error, mean_absolute_error, mean_absolute_percentage_error, max_error
from mpl_toolkits.mplot3d import Axes3D
from scipy.interpolate import griddata
from autogluon.tabular import TabularDataset, TabularPredictor
import warnings
warnings.filterwarnings('ignore')
# plt.rcParams['font.sans-serif'] =['Times New Roman'] 
plt.rcParams['axes.unicode_minus'] = False
plt.rcParams['font.family'] = ['STFangsong']
plt.rcParams['xtick.direction'] = 'in'
plt.rcParams['ytick.direction'] = 'in'
pd.set_option('display.max_columns', False)
pd.set_option('display.max_rows', False)


# ————————————————————产量预测模块————————————————————————————
from production import mzc_metrics
from production import model_train
# 导入数据
df_data = pd.read_excel('./01-参数团法-工程-地质-一体化数据库.xlsx')
# 选择目标列
target_label = '30天累产油'
# 划分数据集
label = target_label
df_train,df_test=train_test_split(df_data, test_size=0.2, random_state=42,shuffle =True, stratify =None)
X_train = df_train.drop(target_label, axis=1)
X_test  = df_test.drop(target_label, axis=1)
Y_train = df_train[[target_label]]
Y_test  = df_test[[target_label]]
# 调用预测函数
label = target_label
time_limit = 7200
k_folds    = 10
predictor_best, predictor_best_Ytrain, predictor_best_Ytest, Result_predictor_best = model_train(df_train, label, 7200, 10)


# ——————————————————————————参数优化模块————————————————————————————
from opt import objective_function
# 输入固定值地质参数
geo_input = {
    '垂厚m': 2.1,
    '地层电阻率Ω.m': 5.6,
    '孔隙度%': 22.9,
    '平均渗透率mD': 565.0,
    '含烃饱和度%': 50.0,
    '泥质含量%': 17.4}

# 创建空的DataFrame用于保存迭代结果
opt_results = pd.DataFrame(columns=['设计充填系数', '最大排量', '最大砂比', '最大砂量', '砂浆量', '射孔簇数', '射孔测深', '射孔垂深', '净射孔垂深充填系数', '设计净液量', '预测产量值'])

# 设置工程参数限制
enginnering_pbounds = {'设计充填系数': (0, 1400), 
           '最大排量': (11.9, 20), 
           '最大砂比': (4, 9.3), 
           '最大砂量': (11002, 101170),
           '砂浆量': (0, 10500), 
           '射孔簇数': (1, 17), 
           '射孔测深': (3.5, 132.9), 
           '射孔垂深': (3, 102.1),
           '净射孔垂深充填系数': (270.0, 1561), 
           '设计净液量': (33, 250)}

# 优化模型调用
optimizer = BayesianOptimization(f=objective_function, pbounds=enginnering_pbounds, random_state=1)
optimizer.maximize(init_points=5, n_iter=100)

# 输出优化目标产量与施工参数值
print(optimizer.max)